import { type MutableRefObject, type Ref, type RefCallback } from "react";
export type ModalDefaultState = Record<string, unknown>;
export type ModalRef<T extends ModalDefaultState = ModalDefaultState> = {
    handleOpen: (e: React.MouseEvent<HTMLElement> | undefined, initialData?: T) => void;
    handleClose: () => void;
    nodeRef: MutableRefObject<HTMLDialogElement | null>;
};
export type ModalState<T extends ModalDefaultState = ModalDefaultState> = T;
export type UseModalOptions = {
    /**
     * Option to determine if the dialog should be closed
     * by clicking on the ::backdrop element
     * @default false
     */
    closeOnBackdropClick?: boolean;
    /**
     * The default functionality of a dialog is to close on the
     * press of the escape key. There are instances where we don't want to close
     * the dialog either due to other escape key listeners for popovers or for
     * other reasons such as destructive actions during wizards in dialogs.
     * Adding this pop will disable the functionality of closing the dialog
     * with the escape key
     * @default false
     */
    disableCloseOnEscapePress?: boolean;
    /**
     * A general handler to do something after the dialog
     * full closes
     */
    onClose?: () => void;
};
/**
 * A custom hook that can turn any dialog element into a modal dialog.
 *
 * This hook provides a modal dialog with the ability to open, close, and handle specific events.
 * It integrates with the `usePortal` hook to manage the portal for rendering the modal dialog in the DOM.
 * The hook returns a set of properties and functions to control the modal's behavior.
 *
 * @example
 * // Example usage:
 * const modalRef = useRef(null);
 * const { dialogRef, Portal } = useModalDialog({
 *   ref: modalRef,
 *   closeOnBackdropClick: true,
 *   onClose: () => console.log('Modal closed'),
 * });
 *
 * return (
 *   <Portal>
 *     <dialog ref={dialogRef}>
 *       <p>Modal Content</p>
 *       <button onClick={() => modalRef.current.handleClose()}>Close</button>
 *     </dialog>
 *   </Portal>
 * );
 */
export declare const useModalDialog: <T extends ModalDefaultState = ModalDefaultState>(params: UseModalOptions & {
    ref: MutableRefObject<ModalRef<T>> | Ref<ModalRef<T>>;
}) => {
    isOpen: boolean;
    dialogRef: RefCallback<HTMLDialogElement>;
    dialogState: T | undefined;
    closeModal: () => Promise<void>;
};
//# sourceMappingURL=useModalDialog.d.ts.map